import { getCurrentInstance } from "vue";
import { u as useCurrentComponentId } from "./useCurrentComponentId.mjs";
const TELEPORT_FROM_ATTR = "data-va-teleported-from";
const TELEPORT_ATTR = "data-va-teleported";
const findTeleportedFrom = (el) => {
  if (!el) {
    return null;
  }
  const teleportId = el.getAttribute(TELEPORT_ATTR);
  if (teleportId === null) {
    return findTeleportedFrom(el.parentElement);
  }
  return document.querySelector(`[${TELEPORT_FROM_ATTR}="${teleportId}"]`);
};
const useTeleported = () => {
  var _a;
  const componentId = useCurrentComponentId();
  const scopedDataV = (_a = getCurrentInstance()) == null ? void 0 : _a.vnode.scopeId;
  return {
    teleportFromAttrs: {
      [TELEPORT_FROM_ATTR]: componentId
    },
    teleportedAttrs: {
      [TELEPORT_ATTR]: componentId,
      [`data-v-${scopedDataV}`]: ""
    },
    findTeleportedFrom
  };
};
export {
  findTeleportedFrom as f,
  useTeleported as u
};
//# sourceMappingURL=useTeleported.mjs.map
