import { type Ref } from 'vue';
import { type VaForm } from '../../components';
import { Form } from './types';
/**
 * Provides access to the form instance.
 *
 * @param ref - Form instance or template ref
 *
 * @example
 *
 * ```vue
 * <template>
 *   <va-form ref="myForm">...</va-form>
 * </template>
 *
 * <script setup>
 *  const { isValid, errorMessages, validate, reset, resetValidation, focus } = useForm('myForm')
 * </script>
 * ```
 */
export declare const useForm: <Names extends string = string>(elRef?: string | Ref<typeof VaForm>) => Form<Names> & {
    formRef: Ref<unknown>;
};
