import type { I18nConfig } from '../services/i18n';
/**
 * @see https://vuestic.dev/en/services/i18n
 *
 * Composable, that allows user to redefine text values used in Vuestic components.
 *
 * @example
 *
 * Use `mergeIntoConfig` if your i18n locale changed to change text values inside Vuestic components.
 *
 * ```js
 * import { useI18nConfig } from 'vuestic-ui'
 * import { useI18n } from 'vue-i18n'
 *
 * const { locale, messages } = useI18n()
 * const { mergeIntoConfig } = useI18nConfig()
 *
 * watch(locale, (newLocale) => {
 *  mergeIntoConfig(messages[newLocale])
 * })
 * ```
 */
export declare const useI18nConfig: () => {
    config: import("vue").ComputedRef<{
        search: string;
        noOptions: string;
        ok: string;
        cancel: string;
        uploadFile: string;
        undo: string;
        dropzone: string;
        fileDeleted: string;
        closeAlert: string;
        backToTop: string;
        toggleDropdown: string;
        carousel: string;
        goPreviousSlide: string;
        goNextSlide: string;
        goSlide: string;
        slideOf: string;
        close: string;
        openColorPicker: string;
        colorSelection: string;
        colorName: string;
        decreaseCounter: string;
        increaseCounter: string;
        selectAllRows: string;
        sortColumnBy: string;
        selectRowByIndex: string;
        resetDate: string;
        nextPeriod: string;
        switchView: string;
        previousPeriod: string;
        removeFile: string;
        reset: string;
        pagination: string;
        goToTheFirstPage: string;
        goToPreviousPage: string;
        goToSpecificPage: string;
        goToSpecificPageInput: string;
        goNextPage: string;
        goLastPage: string;
        currentRating: string;
        voteRating: string;
        optionsFilter: string;
        splitPanels: string;
        movePaginationLeft: string;
        movePaginationRight: string;
        resetTime: string;
        closeToast: string;
        selectedOption: string;
        noSelectedOption: string;
        breadcrumbs: string;
        counterValue: string;
        selectedDate: string;
        selectedTime: string;
        progressState: string;
        color: string;
        next: string;
        back: string;
        finish: string;
        step: string;
        progress: string;
        loading: string;
        sliderValue: string;
        switch: string;
        inputField: string;
    }>;
    mergeIntoConfig: (newConfig: Partial<I18nConfig>) => void;
};
